@@ -7,11 +7,12 @@
    Permission is granted to copy and use this program provided no fee is
    charged for it and provided that this copyright notice is not removed. */
 
-#define VERSION "3.68"
+#define VERSION "3.69"
 
 /* Debugging options */
-/* Define this to disable assertions */
-#define NDEBUG
+/* Define this to disable assertions ...
+   but this leads to 'unused variable' warnings */
+/*#define NDEBUG*/
 
 /* Define this to enable debugging code */
 /* #define DEBUG */
