@@ -75,7 +75,7 @@ void   emboss_getoptions(char *pgm, int argc, char *argv[])
     AjPStr gammamethod = NULL;
     AjPFloat basefreq;
     AjPFloat arrayval; 
-  boolean ttr;
+    /*boolean ttr;*/
 
   ctgry = false;
   categs = 1;
@@ -95,7 +95,7 @@ void   emboss_getoptions(char *pgm, int argc, char *argv[])
   human = false;
   similarity = false;
   ttratio = 2.0;
-  ttr = false;
+  /*ttr = false;*/
   weights = false;
   printdata = false;
   progress = true;
@@ -103,7 +103,7 @@ void   emboss_getoptions(char *pgm, int argc, char *argv[])
   datasets = 1;
   matrix_flags = MAT_MACHINE;
 
-    embInitP (pgm, argc, argv, "PHYLIPNEW");
+  embInitPV(pgm, argc, argv, "PHYLIPNEW",VERSION);
 
     seqsets = ajAcdGetSeqsetall("sequence");
 
