@@ -214,8 +214,7 @@ void emboss_getoptions(char *pgm, int argc, char *argv[])
   mulsets = false;
   datasets = 1;
 
-    embInitP (pgm, argc, argv, "PHYLIPNEW");
-
+  embInitPV(pgm, argc, argv, "PHYLIPNEW",VERSION);
 
     seqsets = ajAcdGetSeqsetall("sequence");
 
@@ -2426,10 +2425,9 @@ void maketree(void)
       freex(nonodes2, bestree2.nodep);
   }
   if (progress) {
-    printf("\n\nOutput written to file \"%s\"\n\n", outfilename);
+    printf("\nOutput written to file \"%s\"\n", outfilename);
     if (trout)
-      printf("Tree also written onto file \"%s\"\n", outtreename);
-    putchar('\n');
+      printf("\nTree also written onto file \"%s\"\n", outtreename);
   }
 }  /* maketree */
 
@@ -2501,7 +2499,7 @@ int main(int argc, Char *argv[])
   }
 
   clean_up();
-  printf("Done.\n\n");
+  printf("\nDone.\n\n");
 #ifdef WIN32
   phyRestoreConsoleAttributes();
 #endif
