@@ -203,7 +203,7 @@ void emboss_getoptions(char *pgm, int argc, char *argv[])
   datasets = 1;
   mulsets = false;
 
-    embInitP (pgm, argc, argv, "PHYLIPNEW");
+  embInitPV(pgm, argc, argv, "PHYLIPNEW",VERSION);
 
     seqsets = ajAcdGetSeqsetall("sequence");
 
@@ -744,7 +744,7 @@ static boolean nuview(node *p)
 
   /* At this point, all views downstream should be initialized.
    * If not, we have a problem. */
-  assert( invalid_descendant_view(p) == NULL );
+  /*assert( invalid_descendant_view(p) == NULL );*/
 
   /* Allocate the structure and blocks therein for variables used in
      this function */
@@ -1054,7 +1054,7 @@ static void dnamlk_add(node *below, node *newtip, node *newfork)
   boolean success;
 
   assert( all_tymes_valid(curtree.root, 0.98*MIN_BRANCH_LENGTH, false) );
-  assert( floating_fork(newfork) );
+  /*assert( floating_fork(newfork) );*/
   assert( newtip->back == NULL );
 
   /* Get parent nodelets */
@@ -2000,9 +2000,9 @@ static void maketree(void)
   
   if (jumb == njumble) {
     if (progress) {
-      printf("\nOutput written to file \"%s\"\n\n", outfilename);
+      printf("\nOutput written to file \"%s\"\n", outfilename);
       if (trout)
-        printf("Tree also written onto file \"%s\"\n\n", outtreename);
+        printf("\nTree also written onto file \"%s\"\n", outtreename);
     }
     free(contribution);
     freex(nonodes, curtree.nodep);
@@ -2067,7 +2067,7 @@ int main(int argc, Char *argv[])
   fixmacfile(outfilename);
   fixmacfile(outtreename);
 #endif
-  printf("Done.\n\n");
+  printf("\nDone.\n\n");
 #ifdef WIN32
   phyRestoreConsoleAttributes();
 #endif
